==> openjdk-13_13.0.7+5.orig.tar.xz: openjdk-13-13.0.7+5/src/hotspot/share/gc/z/zThreadLocalAllocBuffer.hpp <==
/*
 * Copyright (c) 2018, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#ifndef SHARE_GC_Z_ZTHREADLOCALALLOCBUFFER_HPP
#define SHARE_GC_Z_ZTHREADLOCALALLOCBUFFER_HPP

#include "gc/shared/threadLocalAllocBuffer.hpp"
#include "gc/z/zValue.hpp"
#include "memory/allocation.hpp"

class ZThreadLocalAllocBuffer : public AllStatic {
private:
  static ZPerWorker<ThreadLocalAllocStats>* _stats;

public:
  static void initialize();

  static void reset_statistics();
  static void publish_statistics();

  static void retire(Thread* thread);
  static void remap(Thread* thread);
};

#endif // SHARE_GC_Z_ZTHREADLOCALALLOCBUFFER_HPP

==> openjdk-20_20.0.2+9.orig.tar.xz: openjdk-20-20.0.2+9/src/hotspot/share/gc/z/zThreadLocalAllocBuffer.hpp <==
/*
 * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

#ifndef SHARE_GC_Z_ZTHREADLOCALALLOCBUFFER_HPP
#define SHARE_GC_Z_ZTHREADLOCALALLOCBUFFER_HPP

#include "gc/shared/threadLocalAllocBuffer.hpp"
#include "gc/z/zValue.hpp"
#include "memory/allStatic.hpp"

class JavaThread;

class ZThreadLocalAllocBuffer : public AllStatic {
private:
  static ZPerWorker<ThreadLocalAllocStats>* _stats;

public:
  static void initialize();

  static void reset_statistics();
  static void publish_statistics();

  static void retire(JavaThread* thread, ThreadLocalAllocStats* stats);
  static void remap(JavaThread* thread);
  static void update_stats(JavaThread* thread);
};

#endif // SHARE_GC_Z_ZTHREADLOCALALLOCBUFFER_HPP
